#include <stdio.h>
#include <time.h>
#include <math.h>

/* Input time is in GMT, either specified as an argument to this program, or */
/* the current time is chosen. */


main(argc, argv)
int argc;
char *argv[];
{
    float hours, modelWind, observedWind, ships, j[11];

    int num;
    long secs;
    char startDate[180];
    long startTime;
    long obsTime;
    long offset;

    struct tm *gmt;
    long numDate;
    long numTime;
    long nowTime;

    struct tm st;

    FILE *infile = 0;
    FILE *outfile = 0;

    if (argc < 3)
	{
	    fprintf(stderr,"usage: %s inputFileName outputFileName <startTime yymmdd/hhmm>\n", argv[0]);
	    exit(-1);
	}

    infile = fopen(argv[1], "r");
    outfile = fopen(argv[2], "w+");

    if (argc > 3)
	{

	    nowTime = time(0);

	    strcpy(startDate, argv[3]);
	
	    numDate = atoi(startDate);
	    numTime = atoi(&startDate[7]);
	    
	    printf("Date: %06d Time: %d\n",numDate, numTime);

	    st.tm_sec = 0;
	    st.tm_min = numTime %100;
	    st.tm_hour = numTime/100;
	    st.tm_year = numDate / 10000;
	    if (st.tm_year < 69)
		st.tm_year += 100;
	    

	    /* month is represented as 0...11 */
	    st.tm_mon = -1 + ((numDate / 100) % 100);
	    st.tm_mday = numDate % 100;
	    st.tm_isdst = 0;
	    st.tm_zone="GMT";
	    startTime = mktime(&st);

	    offset = difftime(  mktime(gmtime(&nowTime)), mktime(localtime(&nowTime)));

	    startTime -= offset;

	    printf("StartTime: %s\n", asctime(gmtime(&startTime)));
	}
    else
	{
	    startTime = time(0);
	    printf("StartTime: %s\n", asctime(gmtime(&startTime)));
	}

    if (ferror(infile))
	{
	    printf("Error opening inputFile: %d\n", ferror(infile));
	    exit(-2);
	}
    if (ferror(outfile))
	{
	    printf("Error opening outputFile: %d\n", ferror(outfile));
	    exit(-2);
	}

    /* Header information required by gempak */
    fprintf(outfile, "PARM = mwsk;owsk;swsk\n");
    fprintf(outfile, "\n");
    fprintf(outfile, "STN  YYMMDD/HHMM    mwsk        owsk            swsk\n");



    while (!feof(infile))
	{
	    num = fscanf(infile," %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f", &hours, &modelWind, &observedWind, 
&j[0], &j[1], &j[2], &j[3], &j[4], &j[5], &j[6], &j[7], &j[8], &j[9], &j[10], 
&ships); 

	    if (num < 5)
		continue;

	    if (hours < 0)
		continue;

	    secs = floor(hours * 60.0 * 60.0);
	    obsTime = startTime + secs;
	    

	    gmt = gmtime(&obsTime);

	    fprintf(outfile,"BOS %02d%02d%02d/%02d%02d ", gmt->tm_year%100, gmt->tm_mon+1,
		    gmt->tm_mday, 
		    gmt->tm_hour, gmt->tm_min);

	    fprintf(outfile, "%f %f %f\n", modelWind, observedWind, ships);

	}


    fclose(infile);
    fclose(outfile);

}
